import requests

def get_request(url,params={},headers='',payload='',):
    return requests.request("GET", requests.get(url,params=params).url, headers=headers, data=payload)

def post_requst(url,headers,payload=''):
    return requests.request("POST", url, headers=headers, data=payload)

def delete_request(url,headers,payload=''):
    return requests.request("DELETE", url, headers=headers, data=payload)


# -*- coding: utf-8 -*-
import requests
import time
import hashlib
import hmac
import json
from satang_pro_sdk.get_unix_time import nonce
from satang_pro_sdk.all_request import get_request, post_requst, delete_request
from satang_pro_sdk.satangpro import Satangpro


